@@ -2,6 +2,9 @@
 
 from django import template
 from django.utils.safestring import mark_safe
+from ..utils import LazyEncoder
+
+import types, json
 
 register = template.Library()
 
@@ -15,3 +18,11 @@ def call_view_method(context, method_name, *args, **kwargs):
     del view.current_context
 
     return method_response
+
+
+@register.simple_tag(name="as_json")
+def as_json(data):
+    if isinstance(data, types.GeneratorType):
+        data = tuple(data)
+    json_data = json.dumps(data, cls=LazyEncoder)
+    return mark_safe(json_data)
